RusticError

Struct RusticError 

#[non_exhaustive]
pub struct RusticError { /* private fields */ }
Errors that can result from rustic.

Implementations

Source

impl RusticError

pub fn new(kind: ErrorKind, guidance: impl Into<EcoString>) -> Box<RusticError>

Creates a new error with the given kind and guidance.

pub fn with_source( kind: ErrorKind, guidance: impl Into<EcoString>, source: impl Into<Box<dyn Error + Sync + Send>>, ) -> Box<RusticError>

Creates a new error with the given kind and guidance.

pub fn is_code(&self, code: &str) -> bool

Checks if the error has a specific error code.

pub fn is_incorrect_password(&self) -> bool

Checks if the error is due to an incorrect password

pub fn from<T>(kind: ErrorKind, error: T) -> Box<RusticError>
where T: Error + Display + Send + Sync + 'static,

Creates a new error from a given error.

pub fn display_log(&self) -> String

Returns a String representation for logging purposes.

This is a more concise version of the error message.

Source

impl RusticError

pub fn overwrite_kind(self, value: impl Into<ErrorKind>) -> Box<RusticError>

Attach what kind the error is.

pub fn ask_report(self) -> Box<RusticError>

Ask the user to report the error.

pub fn attach_source( self, value: impl Into<Box<dyn Error + Sync + Send>>, ) -> Box<RusticError>

Attach a chain to the cause of the error.

pub fn overwrite_guidance(self, value: impl Into<EcoString>) -> Box<RusticError>

Attach the error message with guidance.

pub fn append_guidance_line( self, value: impl Into<EcoString>, ) -> Box<RusticError>

Append a newline to the guidance message. This is useful for adding additional information to the guidance.

pub fn prepend_guidance_line( self, value: impl Into<EcoString>, ) -> Box<RusticError>

Prepend a newline to the guidance message. This is useful for adding additional information to the guidance.

pub fn attach_context( self, key: impl Into<EcoString>, value: impl Into<EcoString>, ) -> Box<RusticError>

Attach context to the error.

pub fn overwrite_context( self, value: impl Into<EcoVec<(EcoString, EcoString)>>, ) -> Box<RusticError>

Overwrite context of the error.

Caution

This should not be used in most cases, as it will overwrite any existing contexts. Rather use attach_context for multiple contexts.

pub fn attach_docs_url(self, value: impl Into<EcoString>) -> Box<RusticError>

Attach the URL of the documentation for the error.

pub fn attach_error_code(self, value: impl Into<EcoString>) -> Box<RusticError>

Attach an error code.

pub fn attach_new_issue_url( self, value: impl Into<EcoString>, ) -> Box<RusticError>

Attach the URL of the issue tracker for opening a new issue.

pub fn attach_existing_issue_url( self, value: impl Into<EcoString>, ) -> Box<RusticError>

Attach the URL of an already existing issue that is related to this error.

pub fn attach_severity(self, value: impl Into<Severity>) -> Box<RusticError>

Attach the severity of the error.

pub fn attach_status(self, value: impl Into<Status>) -> Box<RusticError>

Attach the status of the error.

pub fn overwrite_backtrace( self, value: impl Into<Backtrace>, ) -> Box<RusticError>

Overwrite the backtrace of the error.

This should not be used in most cases, as the backtrace is automatically captured.