pub trait BackendChoice {
// Required method
fn to_backend(
&self,
location: BackendLocation,
options: Option<BTreeMap<String, String>>,
) -> RusticResult<Arc<dyn WriteBackend>>;
}Expand description
Trait which can be implemented to choose a backend from a backend type, a backend path and options given as HashMap.
Required Methods
Sourcefn to_backend(
&self,
location: BackendLocation,
options: Option<BTreeMap<String, String>>,
) -> RusticResult<Arc<dyn WriteBackend>>
fn to_backend( &self, location: BackendLocation, options: Option<BTreeMap<String, String>>, ) -> RusticResult<Arc<dyn WriteBackend>>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".